load_font

Function load_font 

pub fn load_font(name_or_path: Option<String>) -> (Arc<Vec<u8>>, FontLoaded)
Loads a given font - falling back to the bundled font if loading from the system, or from the given path fails